PyXMake Developer Guide: PyXMake.VTL.gitlab Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.VTL.gitlab Namespace Reference

## Functions
| datacheck (**kwargs)
| download (package=None, projectid=None, version=".", **kwargs)
| pipeline (token=None, projectid=str(12702), **kwargs)

## Detailed Description

    Triple-use minimum working example for PyXMake.
    Technically, this script runs w/o PyXMake, but the default pipeline refers to the project..

    @note: Execute a GitLab pipeline or a given pipeline job remotely w/o non-default packages.

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          - GitLab X-API-Token

    @date:
          - 12.01.2021

    @author: garb_ma                                      [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

## Function Documentation

## ◆ datacheck()

PyXMake.VTL.gitlab.datacheck | ( | ** | kwargs | ) |

    Return the given input data

Definition at line 39 of file gitlab.py.

## ◆ download()

PyXMake.VTL.gitlab.download | ( |  | package = None,
|  |  | projectid = None,
|  |  | version = ".",
|  | ** | kwargs )

    Download all resources for a package from the default registry

Definition at line 57 of file gitlab.py.

## ◆ pipeline()

PyXMake.VTL.gitlab.pipeline | ( |  | token = None,
|  |  | projectid = str(12702),
|  | ** | kwargs )

    Main function to execute the script if main cannot be imported.
    Otherwise, run a named pipeline for a given project with the given credentials.
    Defaults to running a remote install script on CARA.

Definition at line 102 of file gitlab.py.